@@ -621,8 +621,24 @@ class QueryBuilder:
                 try:
                     # Use utility function to build proper aggregation expression
                     field_expression = build_aggregation_field_expression(field)
-                    # Use original field name as key for the result
-                    group_id[field] = field_expression
+
+                    # Create nested structure for fields with dot notation
+                    parts = field.split(".")
+                    d = group_id
+                    for i, part in enumerate(parts[:-1]):
+                        # If a non-dict value is at the path, it can't be extended
+                        if part in d and not isinstance(d[part], dict):
+                            # To avoid overwriting, you could add a unique suffix, or handle as an error
+                            # For now, let's just print a warning and continue
+                            print(
+                                f"Warning: conflicting path in distinct fields for '{field}' at part '{part}'."
+                            )
+                            d = d.setdefault(f"{part}_{i}", {})
+                        else:
+                            d = d.setdefault(part, {})
+
+                    d[parts[-1]] = field_expression
+
                 except ValueError as e:
                     # Log error and skip invalid field
                     print(f"Warning: Skipping invalid field '{field}' in distinct: {e}")
